==> copilot-24.9.6-sources.jar: com/vaadin/copilot/ide/IdeHandler.java <==
package com.vaadin.copilot.ide;

import static com.vaadin.copilot.Copilot.PREFIX;

import java.util.Optional;

import com.vaadin.base.devserver.DevToolsInterface;
import com.vaadin.copilot.CopilotCommand;
import com.vaadin.flow.internal.JacksonUtils;

import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.node.ObjectNode;

public class IdeHandler extends CopilotCommand {
    private final CopilotIDEPlugin idePlugin;
    private boolean idePluginActive;
    private final Optional<IdeUtils.IDE> ide;

    public IdeHandler(CopilotIDEPlugin idePlugin) {
        this.idePlugin = idePlugin;
        this.ide = IdeUtils.findIde();
    }

    @Override
    public void handleConnect(DevToolsInterface devToolsInterface) {
        idePluginActive = idePlugin.isActive();
        sendIdePluginState(devToolsInterface);
    }

    private void sendIdePluginState(DevToolsInterface devToolsInterface) {
        ObjectNode jsonObject = JacksonUtils.createObjectNode();
        if (idePlugin.isActive()) {
            CopilotIDEPluginProperties props = idePlugin.getProperties();
            jsonObject.put("active", true);
            jsonObject.put("version", props.getVersion());
            jsonObject.set("supportedActions", JacksonUtils.listToJson(props.getSupportedActions()));
            jsonObject.put("ide", props.getIde());
        } else {
            jsonObject.put("active", false);
            ide.ifPresent(value -> jsonObject.put("ide", value.getPluginIde()));
        }
        devToolsInterface.send(PREFIX + "plugin-state", jsonObject);
    }

    @Override
    public boolean handleMessage(String command, JsonNode data, DevToolsInterface devToolsInterface) {
        // User enabled plugin during work
        if (!idePluginActive && idePlugin.isActive()) {
            idePluginActive = true;
            sendIdePluginState(devToolsInterface);
        }

        // User disabled plugin during work
        if (idePluginActive && !idePlugin.isActive()) {
            idePluginActive = false;
            sendIdePluginState(devToolsInterface);
        }

        return false;
    }
}

==> copilot-25.1-20260114.104106-70-sources.jar: com/vaadin/copilot/ide/IdeHandler.java <==
package com.vaadin.copilot.ide;

import static com.vaadin.copilot.Copilot.PREFIX;

import java.util.Optional;

import com.vaadin.base.devserver.DevToolsInterface;
import com.vaadin.copilot.CopilotCommand;
import com.vaadin.flow.internal.JacksonUtils;

import tools.jackson.databind.JsonNode;
import tools.jackson.databind.node.ObjectNode;

public class IdeHandler extends CopilotCommand {
    private final CopilotIDEPlugin idePlugin;
    private boolean idePluginActive;
    private final Optional<IdeUtils.IDE> ide;

    public IdeHandler(CopilotIDEPlugin idePlugin) {
        this.idePlugin = idePlugin;
        this.ide = IdeUtils.findIde();
    }

    @Override
    public void handleConnect(DevToolsInterface devToolsInterface) {
        idePluginActive = idePlugin.isActive();
        sendIdePluginState(devToolsInterface);
    }

    private void sendIdePluginState(DevToolsInterface devToolsInterface) {
        ObjectNode jsonObject = JacksonUtils.createObjectNode();
        if (idePlugin.isActive()) {
            CopilotIDEPluginProperties props = idePlugin.getProperties();
            jsonObject.put("active", true);
            jsonObject.put("version", props.getVersion());
            jsonObject.set("supportedActions", JacksonUtils.listToJson(props.getSupportedActions()));
            jsonObject.put("ide", props.getIde());
        } else {
            jsonObject.put("active", false);
            ide.ifPresent(value -> jsonObject.put("ide", value.getPluginIde()));
        }
        devToolsInterface.send(PREFIX + "plugin-state", jsonObject);
    }

    @Override
    public boolean handleMessage(String command, JsonNode data, DevToolsInterface devToolsInterface) {
        // User enabled plugin during work
        if (!idePluginActive && idePlugin.isActive()) {
            idePluginActive = true;
            sendIdePluginState(devToolsInterface);
        }

        // User disabled plugin during work
        if (idePluginActive && !idePlugin.isActive()) {
            idePluginActive = false;
            sendIdePluginState(devToolsInterface);
        }

        return false;
    }
}
